@@ -1,24 +1,24 @@
 #!/usr/bin/env python
-
+#
 # -*- coding: utf-8 -*-
-
-# Copyright (c) 2013-2018, 2020 Pytroll Community
-
+#
+# Copyright (c) 2013-2018, 2020 Pytroll developers
+#
 # Author(s):
-
+#
 #   Adam.Dybbroe <adam.dybbroe@smhi.se>
 #   Panu Lahtinen <panu.lahtinen@fmi.fi>
-
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -170,7 +170,7 @@ class Seviri(object):
                     wnum = 1. / (1e-4 * self.rsr[chname][sat][:])  # microns to cm
                     self.rsr[chname]['wavenumber'] = wnum[::-1]
                 else:
-                    if type(self.rsr[chname][sat]) is dict:
+                    if isinstance(self.rsr[chname][sat], dict):
                         for name in self.rsr[chname][sat].keys():
                             resp = self.rsr[chname][sat][name][:]
                             self.rsr[chname][sat][name] = resp[::-1]
@@ -197,7 +197,7 @@ class Seviri(object):
             for sat in self.rsr[chname].keys():
                 if sat in ["wavelength", "wavenumber"]:
                     continue
-                if type(self.rsr[chname][sat]) is dict:
+                if isinstance(self.rsr[chname][sat], dict):
                     result[chname][sat] = {}
                     for name in self.rsr[chname][sat].keys():
                         resp = self.rsr[chname][sat][name]
@@ -256,8 +256,6 @@ def generate_seviri_file(seviri, platform_name):
             dset = grp.create_dataset('response', arr.shape, dtype='f')
             dset[...] = arr
 
-    return
-
 
 def main():
     """Main"""
